@@ -1,12 +1,12 @@
 rebuild.ppp<-function(X,id=1:(X$n),rm.id=NULL,add.X=NULL,add.id=paste("add",1:(add.X$n),sep="")){
-  stopifnot(spatstat::is.ppp(X))
+  stopifnot(spatstat.geom::is.ppp(X))
   df.X<-as.data.frame(X)
-  df.X.ppp<-spatstat::ppp(x=df.X$x,y=df.X$y,
+  df.X.ppp<-spatstat.geom::ppp(x=df.X$x,y=df.X$y,
                       xrange=X$window$xrange,yrange=X$window$yrange)
   if(is.null(X$marks)){
-    spatstat::marks(df.X.ppp)=id
+    spatstat.geom::marks(df.X.ppp)=id
   }else{
-    spatstat::marks(df.X.ppp)=data.frame(id=id,X$marks)
+    spatstat.geom::marks(df.X.ppp)=data.frame(id=id,X$marks)
   }
   newX=df.X.ppp
   if (!is.null(rm.id)){
@@ -18,11 +18,11 @@ rebuild.ppp<-function(X,id=1:(X$n),rm.id=NULL,add.X=NULL,add.id=paste("add",1:(a
     if(any(intersect(add.id,id)))
       stop("add.id must different with id")
     if(is.null(add.X$marks)){
-      spatstat::marks(add.X)=add.id
+      spatstat.geom::marks(add.X)=add.id
     }else{
-      spatstat::marks(add.X)=data.frame(id=add.id,add.X$marks)
+      spatstat.geom::marks(add.X)=data.frame(id=add.id,add.X$marks)
     }
-    newX<-spatstat::superimpose(df.X.ppp,add.X)
+    newX<-spatstat.geom::superimpose(df.X.ppp,add.X)
   }
   return(newX)
 }
